Learn R Programming

opalr (version 3.7.0)

opal.project_create: Create a project

Description

Create a project

Usage

opal.project_create(
  opal,
  project,
  database = NULL,
  title = NULL,
  description = NULL,
  tags = NULL,
  exportFolder = NULL,
  internal = FALSE
)

Arguments

opal

Opal object.

project

Name of the project

database

The database name (as declared in Opal) to be used to store project's data. If not provided, the project can have views and resources but no raw tables. If the value is a logical and is TRUE, first the internal flag will be evaluated, otherwise the default database will be selected or the first one if there is no default.

title

The title of the project (optional).

description

The description of the project (optional).

tags

A list of tag names (optional).

exportFolder

The default location of the exported data files in the Opal file system (optional).

internal

When database is TRUE and this flag is TRUE as well, the project will be associated to an internal database (Opal 6.0+ only).

See Also

Other project functions: opal.project(), opal.project_delete(), opal.project_exists(), opal.projects(), opal.projects_databases()

Examples

Run this code
if (FALSE) {
o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
# with named database
opal.project_create(o, 'test', database='opal_data', title='This is a test', tags=list('Test'))
# with internal database
opal.project_create(o, 'test_internal_db', database = TRUE, internal = TRUE)
# with default database
opal.project_create(o, 'test_default_db', database = TRUE)
# no database, for views and resources only
opal.project_create(o, 'test_no_db')
opal.logout(o)
}

Run the code above in your browser using DataLab